==> mega-0.2.3.tar.gz: mega-0.2.3/README.md <==
<h1 align="center">Mega</h1> <br>
<p align="center"> <img src="https://user-images.githubusercontent.com/25558240/49630323-4eb8db80-f9b3-11e8-884a-82331a8096cf.png" | width=210> </p>


<code>mega</code> is an asynchronous infringement discovery tool. It scrapes for titles and download links so that you may issue a swift DMCA takedown notice if your hard work is being sold for nothing more than the bandwidth it costs to download it.


## Table of Contents
- [Setup](#setup)
- [Getting Started](#start)
- [Usage](#usage)
- [License](#license)

<a name="setup"></a>
## Setup
1. Create an account at https://forum.snahp.it/

2. Install dependencies: ```pip3 install -r requirements.txt```

3. Create mega's configuration file: ```python3 mega config create```


<a name="start"></a>
## Getting Started
First, set your credentials in the configuration file:
```sh
$ python3 mega config user.name USERNAME
$ python3 mega config user.pass PASSWORD
```

To check that they're correct, run the above commands but omit USERNAME and PASSWORD.

Next, select the categories you want to check out:
```sh
$ python3 mega config defaults
```

<p float="left">
  <img src="https://user-images.githubusercontent.com/25558240/50239276-6155ec00-0387-11e9-8db7-a488149a4109.png" width="430"/>
  <img src="https://user-images.githubusercontent.com/25558240/50239404-b09c1c80-0387-11e9-8812-9eaeb0ad8289.png" width="430"/>
</p>

After applying your selected categories, you can their view their contents with:
```sh
$ python3 mega
```

<p align="center">
  <img src="https://user-images.githubusercontent.com/25558240/50239695-8008b280-0388-11e9-9be6-ba7c2b8e9ad0.png" width="530"/>
</p>

<a name="usage"></a>
## Usage
```sh
usage: mega [OPTIONS]

mega brings you the latest content as soon as its available.

General options:
    -h, --help         Show this help message and exit
    --version          Show program version and exit
    --config, config   Activate configuration mode
    --search, search   Activate search mode

Configuration options:
   user.name  [NAME]   Show current username or add username to .megarc
   user.pass  [PASS]   Show current password or add password to .megarc
   user.creds          Show current username and password
   defaults            Select categories to request content from
   create              Create configuration file

Movement:
   Normal and Search mode
      j                Page down
      k                Page up
      b                Back to search (search mode only)
      q                Quit

   Default mode
      j, ↑             Move up a listing or category
      k, ↓             Move down a listing or category
      l, ENTER         Select listing, category, or menu option
      →, ←             Move to menu
```


<a name="license"></a>
## License
All files within this repo are released under the [MIT (OSI) License](https://en.wikipedia.org/wiki/MIT_License) as per the [LICENSE](https://github.com/bl0nd/mega/blob/master/LICENSE) file stored in the root of this repo.

==> mega-0.2.4.tar.gz: mega-0.2.4/README.md <==
<h1 align="center">Mega</h1> <br>
<p align="center"> <img src="https://user-images.githubusercontent.com/25558240/49630323-4eb8db80-f9b3-11e8-884a-82331a8096cf.png" | width=210> </p>


<code>mega</code> is an asynchronous infringement discovery tool. It scrapes for titles and download links so that you may issue a swift DMCA takedown notice if your hard work is being sold for nothing more than the bandwidth it costs to download it.


## Table of Contents
- [Setup](#setup)
- [Getting Started](#start)
- [Usage](#usage)
- [License](#license)

<a name="setup"></a>
## Setup
1. Create an account at https://forum.snahp.it/

2. Install mega: ```pip install mega```

3. Create mega's configuration file: ```mega config create```


<a name="start"></a>
## Getting Started
First, set your credentials in the configuration file:
```sh
$ mega config user.name USERNAME
$ mega config user.pass PASSWORD
```

To check that they're correct, run the above commands but omit USERNAME and PASSWORD.

Next, select the categories you want to check out:
```sh
$ mega config defaults
```

<p float="left">
  <img src="https://user-images.githubusercontent.com/25558240/50239276-6155ec00-0387-11e9-8db7-a488149a4109.png" width="430"/>
  <img src="https://user-images.githubusercontent.com/25558240/50239404-b09c1c80-0387-11e9-8812-9eaeb0ad8289.png" width="430"/>
</p>

After applying your selected categories, you can their view their contents with:
```sh
$ mega
```

<p align="center">
  <img src="https://user-images.githubusercontent.com/25558240/50239695-8008b280-0388-11e9-9be6-ba7c2b8e9ad0.png" width="530"/>
</p>

<a name="usage"></a>
## Usage
```sh
usage: mega [OPTIONS]

mega brings you the latest content as soon as its available.

General options:
    -h, --help         Show this help message and exit
    --version          Show program version and exit
    --config, config   Activate configuration mode
    --search, search   Activate search mode

Configuration options:
   user.name  [NAME]   Show current username or add username to .megarc
   user.pass  [PASS]   Show current password or add password to .megarc
   user.creds          Show current username and password
   defaults            Select categories to request content from
   create              Create configuration file

Movement:
   Normal and Search mode
      j                Page down
      k                Page up
      b                Back to search (search mode only)
      q                Quit

   Default mode
      j, ↑             Move up a listing or category
      k, ↓             Move down a listing or category
      l, ENTER         Select listing, category, or menu option
      →, ←             Move to menu
```


<a name="license"></a>
## License
All files within this repo are released under the [MIT (OSI) License](https://en.wikipedia.org/wiki/MIT_License) as per the [LICENSE](https://github.com/bl0nd/mega/blob/master/LICENSE) file stored in the root of this repo.
